@@ -1,7 +1,7 @@
 package Log::ger;
 
 our $DATE = '2020-02-18'; # DATE
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 #IFUNBUILT
 # use strict 'subs', 'vars';
@@ -174,10 +174,12 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.029
+version 0.030
 
 =head1 SYNOPSIS
 
+=head2 Producing logs
+
 In your module (producer):
 
  package Foo;
@@ -185,19 +187,53 @@ In your module (producer):
 
  sub foo {
      ...
-     # produce some logs
-     log_error "an error occurred: %03d - %s", $errcode, $errmsg;
+     # produce some logs. no need to configure output or level.
+     log_error "an error occured: %03d - %s", $errcode, $errmsg;
      ...
      log_debug "http response: %s", $http; # automatic dumping of data
  }
  1;
 
+=head2 Consuming logs
+
+=head3 Choosing an output
+
 In your application (consumer/listener):
 
  use Foo;
- use Log::ger::Output 'Screen';
+ use Log::ger::Output 'Screen'; # configure output
+ # level is by default 'warn'
+ foo(); # the error message is shown, but debug message is not.
 
- foo();
+=head3 Choosing multiple outputs
+
+Instead of screen, you can output to multiple outputs (including multiple
+files):
+
+ use Log::ger::Output 'Composite' => (
+     outputs => {
+         Screen => {},
+         File   => [
+             {conf=>{path=>'/path/to/app.log'}},
+             ...
+         ],
+         ...
+     },
+ );
+
+See L<Log::ger::Manual::Tutorial::481_Output_Composite> for more examples.
+
+=head3 Choosing level
+
+One way to set level:
+
+ use Log::ger::Util;
+ Log::ger::Util::set_level('debug'); # be more verbose
+ foo(); # the error message as well as debug message are now shown
+
+There are better ways, e.g. letting users configure log level via configuration
+file or command-line option. See L<Log::ger::Manual::Tutorial::300_Level> for
+more details.
 
 =head1 DESCRIPTION
 
